@@ -1,42 +1,32 @@
 from asdf.extension import ManifestExtension
 
-from .converters.transform.compound import CompoundConverter
-from .converters.transform.core import SimpleTransformConverter
-from .converters.transform.functional_models import ConstantConverter
-from .converters.transform.mappings import (
-    IdentityConverter,
-    RemapAxesConverter,
-    UnitsMappingConverter,
-)
-from .converters.transform.math_functions import MathFunctionsConverter
-from .converters.transform.polynomial import PolynomialConverter, OrthoPolynomialConverter
-from .converters.transform.projections import ProjectionConverter
-from .converters.transform.rotations import Rotate3DConverter, RotationSequenceConverter
-from .converters.transform.tabular import TabularConverter
-
-from .converters.unit.equivalency import EquivalencyConverter
-from .converters.unit.quantity import QuantityConverter
-from .converters.unit.unit import UnitConverter
-
 from .converters.coordinates.angle import AngleConverter, LatitudeConverter, LongitudeConverter
 from .converters.coordinates.earth_location import EarthLocationConverter
 from .converters.coordinates.frame import FrameConverter, LegacyICRSConverter
 from .converters.coordinates.representation import RepresentationConverter
 from .converters.coordinates.sky_coord import SkyCoordConverter
 from .converters.coordinates.spectral_coord import SpectralCoordConverter
-
+from .converters.fits.fits import AsdfFitsConverter, AstropyFitsConverter
+from .converters.table.table import AsdfTableConverter, AstropyTableConverter, ColumnConverter
 from .converters.time.time import TimeConverter
 from .converters.time.time_delta import TimeDeltaConverter
-
-from .converters.table.table import ColumnConverter, AsdfTableConverter, AstropyTableConverter
-
-from .converters.fits.fits import AstropyFitsConverter, AsdfFitsConverter
-
+from .converters.transform.compound import CompoundConverter
+from .converters.transform.core import SimpleTransformConverter
+from .converters.transform.functional_models import ConstantConverter
+from .converters.transform.mappings import IdentityConverter, RemapAxesConverter, UnitsMappingConverter
+from .converters.transform.math_functions import MathFunctionsConverter
+from .converters.transform.polynomial import OrthoPolynomialConverter, PolynomialConverter
+from .converters.transform.projections import ProjectionConverter
+from .converters.transform.rotations import Rotate3DConverter, RotationSequenceConverter
+from .converters.transform.spline import SplineConverter
+from .converters.transform.tabular import TabularConverter
+from .converters.unit.equivalency import EquivalencyConverter
+from .converters.unit.quantity import QuantityConverter
+from .converters.unit.unit import UnitConverter
 
 TRANSFORM_CONVERTERS = [
     # astropy.modeling.core
     CompoundConverter(),
-
     # astropy.modeling.functional_models
     SimpleTransformConverter(
         ["tag:stsci.edu:asdf/transform/airy_disk2d-*"],
@@ -139,6 +129,26 @@ TRANSFORM_CONVERTERS = [
         ["tag:stsci.edu:asdf/transform/sine1d-*"],
         "astropy.modeling.functional_models.Sine1D",
     ),
+    SimpleTransformConverter(
+        ["tag:stsci.edu:asdf/transform/cosine1d-*"],
+        "astropy.modeling.functional_models.Cosine1D",
+    ),
+    SimpleTransformConverter(
+        ["tag:stsci.edu:asdf/transform/tangent1d-*"],
+        "astropy.modeling.functional_models.Tangent1D",
+    ),
+    SimpleTransformConverter(
+        ["tag:stsci.edu:asdf/transform/arcsine1d-*"],
+        "astropy.modeling.functional_models.ArcSine1D",
+    ),
+    SimpleTransformConverter(
+        ["tag:stsci.edu:asdf/transform/arccosine1d-*"],
+        "astropy.modeling.functional_models.ArcCosine1D",
+    ),
+    SimpleTransformConverter(
+        ["tag:stsci.edu:asdf/transform/arctangent1d-*"],
+        "astropy.modeling.functional_models.ArcTangent1D",
+    ),
     SimpleTransformConverter(
         ["tag:stsci.edu:asdf/transform/trapezoid1d-*"],
         "astropy.modeling.functional_models.Trapezoid1D",
@@ -151,17 +161,14 @@ TRANSFORM_CONVERTERS = [
         ["tag:stsci.edu:asdf/transform/voigt1d-*"],
         "astropy.modeling.functional_models.Voigt1D",
     ),
-
     # astropy.modeling.mappings
     IdentityConverter(),
     RemapAxesConverter(),
     # UnitsMapping is not represented here because
     # it is an astropy-specific transform and not
     # included in the ASDF transform extension.
-
     # astropy.modeling.math_functions
     MathFunctionsConverter(),
-
     # astropy.modeling.physical_models
     SimpleTransformConverter(
         ["tag:stsci.edu:asdf/transform/blackbody-*"],
@@ -176,14 +183,13 @@ TRANSFORM_CONVERTERS = [
         ["tag:stsci.edu:asdf/transform/plummer1d-*"],
         "astropy.modeling.physical_models.Plummer1D",
     ),
-
     # astropy.modeling.polynomial
     PolynomialConverter(),
     OrthoPolynomialConverter(),
     # SIP and InverseSIP are deliberately excluded because they
     # are FITS-specific and can be easily represented by a
     # simple combination of existing models.
-
+    SplineConverter(),
     # astropy.modeling.powerlaws
     SimpleTransformConverter(
         ["tag:stsci.edu:asdf/transform/broken_power_law1d-*"],
@@ -205,7 +211,6 @@ TRANSFORM_CONVERTERS = [
         ["tag:stsci.edu:asdf/transform/smoothly_broken_power_law1d-*"],
         "astropy.modeling.powerlaws.SmoothlyBrokenPowerLaw1D",
     ),
-
     # astropy.modeling.projections
     SimpleTransformConverter(
         ["tag:stsci.edu:asdf/transform/affine-*"],
@@ -346,7 +351,6 @@ TRANSFORM_CONVERTERS = [
         "astropy.modeling.projections.Pix2Sky_ZenithalPerspective",
         "astropy.modeling.projections.Sky2Pix_ZenithalPerspective",
     ),
-
     # astropy.modeling.rotations
     SimpleTransformConverter(
         ["tag:stsci.edu:asdf/transform/rotate2d-*"],
@@ -354,7 +358,6 @@ TRANSFORM_CONVERTERS = [
     ),
     Rotate3DConverter(),
     RotationSequenceConverter(),
-
     # astropy.modeling.tabular
     TabularConverter(),
 ]
@@ -384,13 +387,7 @@ TRANSFORM_EXTENSIONS = [
 ]
 
 
-ASTROPY_CONVERTERS = [
-    EquivalencyConverter(),
-    UnitsMappingConverter(),
-    AngleConverter(),
-    LatitudeConverter(),
-    LongitudeConverter(),
-    EarthLocationConverter(),
+COORDINATES_CONVERTERS = [
     FrameConverter(
         "tag:astropy.org:astropy/coordinates/frames/baseframe-*",
         "astropy.coordinates.baseframe.BaseCoordinateFrame",
@@ -436,15 +433,31 @@ ASTROPY_CONVERTERS = [
         "astropy.coordinates.builtin_frames.gcrs.PrecessedGeocentric",
     ),
     LegacyICRSConverter(),
+    AngleConverter(),
+    LatitudeConverter(),
+    LongitudeConverter(),
+    EarthLocationConverter(),
     RepresentationConverter(),
     SkyCoordConverter(),
     SpectralCoordConverter(),
+]
+
+
+ASTROPY_CONVERTERS = [
+    EquivalencyConverter(),
+    UnitsMappingConverter(),
     TimeDeltaConverter(),
     AstropyTableConverter(),
     AstropyFitsConverter(),
 ]
 
 
+COORDINATES_EXTENSION = ManifestExtension.from_uri(
+    "asdf://asdf-format.org/astronomy/coordinates/manifests/coordinates-1.0.0",
+    converters=COORDINATES_CONVERTERS,
+)
+
+
 ASTROPY_EXTENSION = ManifestExtension.from_uri(
     "asdf://astropy.org/astropy/manifests/astropy-1.0.0",
     # This prevents a warning about a missing extension when opening
